//
//  T. Hebbeker 1.0  2004-10-07
//              1.1  2008-03-26   print in different formats
//                                remove labeling x and y axes
//              1.2  2019-02-28   print in different formats
//
// start this macro in root with   .x  ./plot.C
//
// input files like 91gev.root and hadrons.root must have been
//  produced before by analyse.exe  
//

void plot()
{

// say hello

   cout << endl 
        << " >>> plot.C <<<  version 1.2  T.H.  2019-02-28 " 
        << endl << endl;

// some general options 
   gStyle->SetOptStat(0);

// open frame, white color
   TCanvas *canvas1 = new TCanvas("canvas1", "test plot");
   canvas1->SetFillColor(10);

// define input root file with L3 data 
     TFile *file_L3 = TFile::Open("89gev.root");
      
// plot data histogram, after normalization, with some options
   TH1F *histo_L3 = (TH1F*)file_L3->Get("histo1");
   histo_L3->SetNormFactor(1.);
   histo_L3->SetMarkerStyle(20);
   histo_L3->SetMarkerSize(2.0);
   histo_L3->SetMarkerColor(2);
   histo_L3->Draw("P"); 

// define input root file with Monte Carlo
   TFile *file_MC = new TFile("hadrons.root");

// plot MC histogram, after normalization, with some options
   TH1F *histo_MC = (TH1F*)file_MC->Get("histo1");
   histo_MC->SetNormFactor(1.);
   histo_MC->SetLineColor(3);
   histo_MC->SetLineWidth(2);
   histo_MC->Draw("same"); 

// add some text

   TLatex *text1 = new TLatex(11.2,0.25,"L3");
   text1->SetTextColor(2);
   text1->Draw();

   TLatex *text2 = new TLatex(12.6,0.2,"Monte Carlo");
   text2->SetTextColor(3);
   text2->Draw();

// print plot as jpg, gif, png, pdf file
   canvas1->Print("plot.jpg");
   canvas1->Print("plot.gif");
   canvas1->Print("plot.png");
   canvas1->Print("plot.pdf");
   
}
